import {
  select,
  csv,
  scaleLinear,
  extent,
  axisLeft,
  axisBottom,
  line,
  scaleTime,
  format
} from 'd3';

async function render(){
  
  const data = await csv('data.csv');
  
  data.forEach(d => {
    d['Ano'] = new Date(d['Ano']);
    d['População total'] = +d['População total'];
  });
  
  const svg = select('svg');
  const outerWidth = svg.attr('width');
  const outerHeight = svg.attr('height');
  const margin = {
    bottom: 70,
    top: 70,
    left: 120,
    right: 30
  };
  const width = outerWidth - margin.left - margin.right;
  const height = outerHeight - margin.top - margin.bottom;
  
  const xLabel = 'Ano';
  const yLabel = 'População Total';
  
  const xValue = d => d['Ano'];
  const yValue = d => d['População total'] ;
  
  const title = `${xLabel} X ${yLabel}`;
  
  const g = svg.append('g')
  	.attr('transform', `translate(${margin.left}, ${margin.top})`);

  const xScale = scaleTime()
  	.domain(extent(data, d => xValue(d)))
  	.range([0, width])
  	.nice();
  

  const yScale = scaleLinear()
  	.domain(extent(data, d => yValue(d)).reverse())
  	.range([0, height])
  	.nice();
  
  const lineGenerator = line()
  	.x(d => xScale(xValue(d)))
  	.y(d => yScale(yValue(d)));
  
  g.append('path')
  	.attr('class', 'line-path')
  	.attr('d', lineGenerator(data));  
  
  
  const xAxis = axisBottom(xScale)
  	.tickSize(-height)
  	.tickSizeOuter(0)
  	.tickPadding(15);
  
  const yAxisFormat = number => format('.3s')(number).replace('M', 'Mi');
  
  const yAxis = axisLeft(yScale)
  	.tickSize(-width)
  	.tickSizeOuter(0)
  	.tickPadding(10)
  	.tickFormat(yAxisFormat);
  
  const xAxisGroup = g.append('g')
    .call(xAxis)
  	.attr('transform', `translate(0, ${height})`);
 
  g.append('g')
    .call(yAxis)
  
  g.append('text')
    .text(title)
  	.attr('y', -20)
  	.attr('class', 'title')
  	.attr('transform', `translate(${width/2}, 0)`)
  	.style('text-anchor', 'middle');
  
  g.append('text')
  	.text(xLabel)
  	.attr('class', 'label')
  	.attr('y', height + margin.bottom)
  	.attr('x', width/2);  
  
  const tamanhoFonteLabel = select('.label').style('font-size');
  
  svg.append('text')
  	.text(yLabel)
  	.attr('class', 'label')
  	.attr('transform', 'rotate(-90)')
  	.attr('y', tamanhoFonteLabel)
  	.attr('x', -outerHeight/2);
  
}

r